import 'package:dio/dio.dart';
import 'package:injectable/injectable.dart';
import 'package:retrofit/http.dart';

import '../model/request/account_info_request.dart';
import '../model/request/compare_face_request.dart';
import '../model/request/create_session_request.dart';
import '../model/request/process_request.dart';
import '../model/response/account_info_response.dart';
import '../model/response/create_session_response.dart';
import '../model/response/process_response.dart';

part 'soliq_id_api.g.dart';

@RestApi()
@Singleton()
abstract class SoliqIdApi {
  @factoryMethod
  factory SoliqIdApi(Dio dio) = _SoliqIdApi;

  @POST('soliq-id/get-account-info')
  Future<AccountInfoResponse> getAccountInfo(
    @Body() AccountInfoRequest request,
  );

  @POST('soliq-id/create-session')
  Future<CreateSessionResponse> session(
    @Body() CreateSessionRequest request,
  );

  @POST('soliq-id/set-process')
  Future<ProcessResponse> logsApi(
    @Body() ProcesseRequest request,
  );

  @POST('soliq-id/compare-face')
  Future<ProcessResponse> faceCompare(
    @Body() CompareFaceRequest request,
  );
}
